from typing import Any, Dict, List, Type, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="MtmEditorReq")


@_attrs_define
class MtmEditorReq:
    """
    Attributes:
        option (str):
        prompt (str):
        command (Union[None, Unset, str]):
    """

    option: str
    prompt: str
    command: Union[None, Unset, str] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        option = self.option

        prompt = self.prompt

        command: Union[None, Unset, str]
        if isinstance(self.command, Unset):
            command = UNSET
        else:
            command = self.command

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "option": option,
                "prompt": prompt,
            }
        )
        if command is not UNSET:
            field_dict["command"] = command

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        option = d.pop("option")

        prompt = d.pop("prompt")

        def _parse_command(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        command = _parse_command(d.pop("command", UNSET))

        mtm_editor_req = cls(
            option=option,
            prompt=prompt,
            command=command,
        )

        mtm_editor_req.additional_properties = d
        return mtm_editor_req

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="RagRetrievalReq")


@_attrs_define
class RagRetrievalReq:
    """
    Attributes:
        collection (Union[None, str]):
        query (str):
        limit (Union[Unset, int]):  Default: 10.
    """

    collection: Union[None, str]
    query: str
    limit: Union[Unset, int] = 10
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        collection: Union[None, str]
        collection = self.collection

        query = self.query

        limit = self.limit

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "collection": collection,
                "query": query,
            }
        )
        if limit is not UNSET:
            field_dict["limit"] = limit

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()

        def _parse_collection(data: object) -> Union[None, str]:
            if data is None:
                return data
            return cast(Union[None, str], data)

        collection = _parse_collection(d.pop("collection"))

        query = d.pop("query")

        limit = d.pop("limit", UNSET)

        rag_retrieval_req = cls(
            collection=collection,
            query=query,
            limit=limit,
        )

        rag_retrieval_req.additional_properties = d
        return rag_retrieval_req

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

if TYPE_CHECKING:
    from ..models.editor import Editor
    from ..models.interview_state_references_type_0 import InterviewStateReferencesType0


T = TypeVar("T", bound="InterviewState")


@_attrs_define
class InterviewState:
    """
    Attributes:
        messages (List[Any]):
        references (Union['InterviewStateReferencesType0', None]):
        editor (Union['Editor', None]):
    """

    messages: List[Any]
    references: Union["InterviewStateReferencesType0", None]
    editor: Union["Editor", None]
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        from ..models.editor import Editor
        from ..models.interview_state_references_type_0 import InterviewStateReferencesType0

        messages = self.messages

        references: Union[Dict[str, Any], None]
        if isinstance(self.references, InterviewStateReferencesType0):
            references = self.references.to_dict()
        else:
            references = self.references

        editor: Union[Dict[str, Any], None]
        if isinstance(self.editor, Editor):
            editor = self.editor.to_dict()
        else:
            editor = self.editor

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "messages": messages,
                "references": references,
                "editor": editor,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.editor import Editor
        from ..models.interview_state_references_type_0 import InterviewStateReferencesType0

        d = src_dict.copy()
        messages = cast(List[Any], d.pop("messages"))

        def _parse_references(data: object) -> Union["InterviewStateReferencesType0", None]:
            if data is None:
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                references_type_0 = InterviewStateReferencesType0.from_dict(data)

                return references_type_0
            except:  # noqa: E722
                pass
            return cast(Union["InterviewStateReferencesType0", None], data)

        references = _parse_references(d.pop("references"))

        def _parse_editor(data: object) -> Union["Editor", None]:
            if data is None:
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                editor_type_0 = Editor.from_dict(data)

                return editor_type_0
            except:  # noqa: E722
                pass
            return cast(Union["Editor", None], data)

        editor = _parse_editor(d.pop("editor"))

        interview_state = cls(
            messages=messages,
            references=references,
            editor=editor,
        )

        interview_state.additional_properties = d
        return interview_state

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

T = TypeVar("T", bound="ChatBotUiState")


@_attrs_define
class ChatBotUiState:
    """
    Attributes:
        is_open_agent_rag_view (Union[None, bool]):
        thread_id (Union[None, str]):
        is_dev (Union[None, bool]):
        is_open_rag_ui (Union[None, bool]):
    """

    is_open_agent_rag_view: Union[None, bool]
    thread_id: Union[None, str]
    is_dev: Union[None, bool]
    is_open_rag_ui: Union[None, bool]
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        is_open_agent_rag_view: Union[None, bool]
        is_open_agent_rag_view = self.is_open_agent_rag_view

        thread_id: Union[None, str]
        thread_id = self.thread_id

        is_dev: Union[None, bool]
        is_dev = self.is_dev

        is_open_rag_ui: Union[None, bool]
        is_open_rag_ui = self.is_open_rag_ui

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "isOpenAgentRagView": is_open_agent_rag_view,
                "threadId": thread_id,
                "isDev": is_dev,
                "isOpenRagUi": is_open_rag_ui,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()

        def _parse_is_open_agent_rag_view(data: object) -> Union[None, bool]:
            if data is None:
                return data
            return cast(Union[None, bool], data)

        is_open_agent_rag_view = _parse_is_open_agent_rag_view(d.pop("isOpenAgentRagView"))

        def _parse_thread_id(data: object) -> Union[None, str]:
            if data is None:
                return data
            return cast(Union[None, str], data)

        thread_id = _parse_thread_id(d.pop("threadId"))

        def _parse_is_dev(data: object) -> Union[None, bool]:
            if data is None:
                return data
            return cast(Union[None, bool], data)

        is_dev = _parse_is_dev(d.pop("isDev"))

        def _parse_is_open_rag_ui(data: object) -> Union[None, bool]:
            if data is None:
                return data
            return cast(Union[None, bool], data)

        is_open_rag_ui = _parse_is_open_rag_ui(d.pop("isOpenRagUi"))

        chat_bot_ui_state = cls(
            is_open_agent_rag_view=is_open_agent_rag_view,
            thread_id=thread_id,
            is_dev=is_dev,
            is_open_rag_ui=is_open_rag_ui,
        )

        chat_bot_ui_state.additional_properties = d
        return chat_bot_ui_state

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

if TYPE_CHECKING:
    from ..models.sub_app import SubApp
    from ..models.sub_web import SubWeb


T = TypeVar("T", bound="ConfigResponse")


@_attrs_define
class ConfigResponse:
    """
    Attributes:
        name (str):
        subapps (List['SubApp']):
        subwebs (List['SubWeb']):
    """

    name: str
    subapps: List["SubApp"]
    subwebs: List["SubWeb"]
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        name = self.name

        subapps = []
        for subapps_item_data in self.subapps:
            subapps_item = subapps_item_data.to_dict()
            subapps.append(subapps_item)

        subwebs = []
        for subwebs_item_data in self.subwebs:
            subwebs_item = subwebs_item_data.to_dict()
            subwebs.append(subwebs_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "name": name,
                "subapps": subapps,
                "subwebs": subwebs,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.sub_app import SubApp
        from ..models.sub_web import SubWeb

        d = src_dict.copy()
        name = d.pop("name")

        subapps = []
        _subapps = d.pop("subapps")
        for subapps_item_data in _subapps:
            subapps_item = SubApp.from_dict(subapps_item_data)

            subapps.append(subapps_item)

        subwebs = []
        _subwebs = d.pop("subwebs")
        for subwebs_item_data in _subwebs:
            subwebs_item = SubWeb.from_dict(subwebs_item_data)

            subwebs.append(subwebs_item)

        config_response = cls(
            name=name,
            subapps=subapps,
            subwebs=subwebs,
        )

        config_response.additional_properties = d
        return config_response

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.section import Section


T = TypeVar("T", bound="Outline")


@_attrs_define
class Outline:
    """
    Attributes:
        page_title (str):
        sections (Union[Unset, List['Section']]):
    """

    page_title: str
    sections: Union[Unset, List["Section"]] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        page_title = self.page_title

        sections: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.sections, Unset):
            sections = []
            for sections_item_data in self.sections:
                sections_item = sections_item_data.to_dict()
                sections.append(sections_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "page_title": page_title,
            }
        )
        if sections is not UNSET:
            field_dict["sections"] = sections

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.section import Section

        d = src_dict.copy()
        page_title = d.pop("page_title")

        sections = []
        _sections = d.pop("sections", UNSET)
        for sections_item_data in _sections or []:
            sections_item = Section.from_dict(sections_item_data)

            sections.append(sections_item)

        outline = cls(
            page_title=page_title,
            sections=sections,
        )

        outline.additional_properties = d
        return outline

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.subsection import Subsection


T = TypeVar("T", bound="Section")


@_attrs_define
class Section:
    """
    Attributes:
        section_title (str):
        description (str):
        subsections (Union[List['Subsection'], None, Unset]):
    """

    section_title: str
    description: str
    subsections: Union[List["Subsection"], None, Unset] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        section_title = self.section_title

        description = self.description

        subsections: Union[List[Dict[str, Any]], None, Unset]
        if isinstance(self.subsections, Unset):
            subsections = UNSET
        elif isinstance(self.subsections, list):
            subsections = []
            for subsections_type_0_item_data in self.subsections:
                subsections_type_0_item = subsections_type_0_item_data.to_dict()
                subsections.append(subsections_type_0_item)

        else:
            subsections = self.subsections

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "section_title": section_title,
                "description": description,
            }
        )
        if subsections is not UNSET:
            field_dict["subsections"] = subsections

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.subsection import Subsection

        d = src_dict.copy()
        section_title = d.pop("section_title")

        description = d.pop("description")

        def _parse_subsections(data: object) -> Union[List["Subsection"], None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                subsections_type_0 = []
                _subsections_type_0 = data
                for subsections_type_0_item_data in _subsections_type_0:
                    subsections_type_0_item = Subsection.from_dict(subsections_type_0_item_data)

                    subsections_type_0.append(subsections_type_0_item)

                return subsections_type_0
            except:  # noqa: E722
                pass
            return cast(Union[List["Subsection"], None, Unset], data)

        subsections = _parse_subsections(d.pop("subsections", UNSET))

        section = cls(
            section_title=section_title,
            description=description,
            subsections=subsections,
        )

        section.additional_properties = d
        return section

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
